# Core Caching Test Results

**Module:** Caching
**Layer:** 0.core
**Generated:** 04-Nov-2025 17:08:41
**Status:** FAILED

---

## Test Execution

**Command:** `python tests/0.core/caching/runner.py`

**Markers:** `xsystem_core and xsystem_caching`

**Options:**
- Verbose output (`-v`)
- Short traceback (`--tb=short`)
- Stop on first failure (`-x`)

---

## Result

❌ Core caching tests FAILED

**Exit Code:** 1

---

*Generated by eXonware test runner - Excellence Edition*
